@@ -1,7 +1,7 @@
 package Tcl;
 use Carp;
 
-$Tcl::VERSION = '0.76';
+$Tcl::VERSION = '0.77';
 
 =head1 NAME
 
@@ -298,7 +298,11 @@ sub call {
     for (my $argcnt=0; $argcnt<=$#args; $argcnt++) {
 	my $arg = $args[$argcnt];
 	my $ref = ref($arg);
-	next unless $ref;
+	#next unless $ref;
+	unless ($ref) {
+	    $args[$argcnt] = "$args[$argcnt]"; # stringifying will prevent from 1 => 1.0 TODO : FIXME
+	    next;
+	}
 	if ($ref eq 'CODE') {
 	    # We have been passed something like \&subroutine
 	    # Create a proc in Tcl that invokes this subroutine (no args)
@@ -368,6 +372,20 @@ sub call {
     }
 }
 
+# wcall is simple wrapper to 'call' but it tries to search $res in %anon_hash
+# This implementation is temporary
+sub wcall {
+    if (wantarray) {
+	return call(@_);
+    } else {
+	my $res = call(@_);
+	if (exists $anon_refs{$res}) {
+	    return $anon_refs{$res};
+	}
+	return $res;
+    }
+}
+
 # create_tcl_sub will create TCL sub that will invoke perl anonymous sub
 # if $events variable is specified then special processing will be
 # performed to provide needed '%' variables
